@@ -2,7 +2,6 @@ import sys
 
 
 def help():
-
     print(
         """
             Set output dir:
@@ -21,11 +20,7 @@ if __name__ == "__main__":
     if len(sys.argv) == 1:
         help()
     elif len(sys.argv) == 2:
-        if sys.argv[1] == "setdir":
-            import maxoptics.configtools.set_save_dir
-        elif sys.argv[1] == "seturl":
-            import maxoptics.configtools.set_url
-        elif sys.argv[1] == "update":
+        if sys.argv[1] == "update":
             from maxoptics.configtools.update import update
 
             update()
