@@ -1,17 +1,17 @@
-from maxoptics.utils.__pyfuture__ import fdict
-from maxoptics.utils.__visualizer__ import arg_description, fillargs
-
-from typing import Callable
-from functools import wraps
 import inspect
+from functools import wraps
+from typing import Callable
+
+from maxoptics.utils.__pyfuture__ import fdict
 
 
 def __post__(func: Callable):
     @wraps(func)
     def wrapper(*args, **kws):
         self, *__args__ = args
-
         try:
+            if self.status == -2:
+                raise self.error
             # Check whether fit the args
             result = self.post(url=func.__name__, **func(*args, **kws))
 
@@ -37,7 +37,6 @@ def data_parser(func: Callable):
     @wraps(func)
     def wrapper(*args, **kws):
         self, *__args__ = args
-        # __kwargs__, __args = fillargs(func, args, kws)
         return TaskFile(
             func(*args, **kws),
             self,
