@@ -1,6 +1,8 @@
 import unittest
+
 from HTMLTestRunner import HTMLTestRunner
-test_dir = ""
+
+test_dir = "tests"
 discover = unittest.defaultTestLoader.discover(test_dir, pattern="*_test.py")
 
 if __name__ == "__main__":
